Stan Math Library: stan/math/rev/mat/vectorize/apply_scalar_unary.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

apply_scalar_unary.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_MAT_VECTORIZE_APPLY_UNARY_SCALAR_HPP
2 #define STAN_MATH_REV_MAT_VECTORIZE_APPLY_UNARY_SCALAR_HPP
3
4 #include <stan/math/prim/mat/vectorize/apply_scalar_unary.hpp>
5 #include <stan/math/rev/core/var.hpp>
6
7 namespace stan {
8
9 namespace math {
10
19 template <typename F>
20 struct apply_scalar_unary<F, stan::math::var> {
24 typedef stan::math::var return_t;
25
32 static inline return_t apply(const stan::math::var& x) {
33 return F::fun(x);
34 }
35 };
36
37 }
38 }
39 #endif
stan::math::apply_scalar_unary< F, stan::math::var >::return_t
stan::math::var return_t
Function return type, which is var.
Definition: apply_scalar_unary.hpp:24
stan::math::apply_scalar_unary< F, stan::math::var >::apply
static return_t apply(const stan::math::var &x)
Apply the function specified by F to the specified argument.
Definition: apply_scalar_unary.hpp:32
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
var.hpp
stan::math::apply_scalar_unary
Base template class for vectorization of unary scalar functions defined by a template class F to a sc...
Definition: apply_scalar_unary.hpp:36
apply_scalar_unary.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.